"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.packageLintAction = void 0;

var _path = require("path");

var _chalk = require("chalk");

var _npmPackageJsonLint = require("npm-package-json-lint");

var _actionConfigs = require("../../../configs/actionConfigs");

var _messageError = require("../../errors/messageError");

var _getFirstExistingFile = require("../../utils/getFirstExistingFile");

const packageLintAction = async (argv, {
  mode,
  path = argv.root
}) => {
  const {
    root,
    cfg,
    log
  } = argv;
  const configFile = await (0, _getFirstExistingFile.getFirstExistingFile)({
    cwd: root,
    files: _actionConfigs.packageLintFiles[mode],
    defaultFile: (0, _path.join)(cfg, `npmpackagejsonlintrc.${mode}.json`)
  });
  log.debug(`Check the package.json (mode: ${mode})`);
  log.debug(`▸ Config: ${configFile}`);
  log.debug(`▸ File: ${path}/package.json`);
  const npmPackageJsonLint = new _npmPackageJsonLint.NpmPackageJsonLint({
    cwd: path,
    configFile,
    patterns: ['./package.json']
  });
  const {
    results
  } = npmPackageJsonLint.lint();

  if (results.length > 1) {
    throw new Error('More than one package.json was checked.');
  }

  const result = results.at(0);

  if (!result) {
    throw new Error('No package.json was checked.');
  }

  if (result.issues.length > 0) {
    const message = result.issues.map(({
      lintId,
      node,
      lintMessage
    }) => {
      const key = node === '' ? 'global' : node;
      const description = lintMessage.split('. ').map(v => `  ∙ ${v.trim()}`).join('\n');
      return `▸ ${(0, _chalk.red)(key)}: ${(0, _chalk.magenta)(lintId)}\n${description}`;
    }).join('\n');
    throw new _messageError.MessageError(message);
  }
};

exports.packageLintAction = packageLintAction;