"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prettierAction = void 0;

var _path = require("path");

var _actionConfigs = require("../../../configs/actionConfigs");

var _execReturn = require("../../cmd/execReturn");

var _getFirstExistingFile = require("../../utils/getFirstExistingFile");

const prettierAction = async ({
  root,
  cfg,
  log
}, {
  write,
  files,
  extension = _actionConfigs.prettierExtensions
}) => {
  const configFile = await (0, _getFirstExistingFile.getFirstExistingFile)({
    cwd: root,
    files: _actionConfigs.prettierConfigFiles,
    defaultFile: (0, _path.join)(cfg, 'prettierrc.json')
  });
  const cmd = (0, _path.join)(root, _actionConfigs.prettierCommand);
  const args = [];
  args.push('--config', configFile);

  if (write) {
    args.push('--write');
  } else {
    args.push('--list-different');
  }

  if (files) {
    if (files.length === 0) {
      log.info('No files found for prettier');
      return;
    }

    args.push(...files);
  } else {
    args.push(`"./**/*.{${extension}}"`);
  }

  log.info('Run prettier');
  await (0, _execReturn.execReturn)({
    cmd,
    args,
    cwd: root,
    log
  });
};

exports.prettierAction = prettierAction;