"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.desc = exports.command = exports.builder = void 0;

var _yargs = require("../cli/yargs");

var _startTask = require("../tasks/startTask");

const command = 'start';
exports.command = command;
const desc = 'Run application directly';
exports.desc = desc;
const options = {
  group: `${command}-Options`
};
const boolOptions = { ...options,
  type: 'boolean'
};
const handler = (0, _yargs.createHandler)(_startTask.startTask);
exports.handler = handler;
const builder = (0, _yargs.createBuilder)(command, yargs => yargs.options({
  watch: { ...boolOptions,
    alias: 'w',
    describe: 'Reload your app on source file changes'
  },
  script: { ...options,
    type: 'string',
    alias: 's',
    describe: 'Script to be called (default: src/index.[ts|js])'
  },
  'build-dependencies': { ...boolOptions,
    alias: 'b',
    describe: 'In a monorepo, all packages are built beforehand'
  },
  'clear-console': { ...boolOptions,
    alias: 'c',
    implies: ['watch'],
    conflicts: ['pino-pretty'],
    describe: 'Clear console on each restart (only with watch mode)'
  },
  'pino-pretty': { ...boolOptions,
    alias: 'p',
    conflicts: ['clear-console'],
    describe: 'Enables the pino log formatter (pino-pretty)'
  }
}));
exports.builder = builder;