"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createProject = void 0;

var _path = require("path");

var _tools = require("@kettil/tools");

var _defaultConfig = require("./defaultConfig");

var _getSetupFilesAfterEnvironment = require("./getSetupFilesAfterEnvironment");

const createProject = settings => (root, workspaces) => {
  if (!(0, _tools.isObject)(settings)) {
    throw new TypeError('createProject requires an object as the first argument');
  }

  const {
    testFolder,
    workspaceFolder,
    color,
    customeConfig = {}
  } = settings;
  const hasWorkspace = (0, _tools.isString)(workspaceFolder);

  if (hasWorkspace && !Object.keys(workspaces).includes(workspaceFolder)) {
    throw new TypeError(`Workspace "${workspaceFolder}" is unknown - createProject({ workspaceFolder: "<name>" })`);
  }

  if (typeof testFolder !== 'string') {
    throw new TypeError('"testFolder" is not a string - createProject({ testFolder: "<name>" })');
  }

  if (typeof color !== 'string') {
    throw new TypeError('"color" is not a color string - createProject({ color: "<color>" })');
  }

  if (!(0, _tools.isObject)(customeConfig)) {
    throw new TypeError('"customeConfig" is not an object - createProject({ customeConfig: { ... } })');
  }

  const pathWorkspace = hasWorkspace ? workspaces[workspaceFolder] : '';
  const configPathSource = hasWorkspace ? `${pathWorkspace}/src` : '<rootDir>/src';
  const configPathTests = hasWorkspace ? `${pathWorkspace}/tests/${testFolder}` : `<rootDir>/tests/${testFolder}`;
  const name = (hasWorkspace ? `${workspaceFolder}:` : '') + testFolder;
  const pathTest = (0, _path.join)(root, configPathTests.replace('<rootDir>', '.'));
  return { ..._defaultConfig.defaultConfig,
    displayName: {
      name,
      color
    },
    roots: [configPathSource, configPathTests],
    testMatch: ['**/*.test.{js,ts,tsx}'],
    testPathIgnorePatterns: ['/node_modules/', '/src/'],
    setupFilesAfterEnv: (0, _getSetupFilesAfterEnvironment.getSetupFilesAfterEnvironment)(pathTest, ['setupTests']),
    ...customeConfig
  };
};

exports.createProject = createProject;