"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.analyseTask = exports.analyseSuffixServices = exports.analyseServices = exports.analysePreServices = void 0;

var _actionConfigs = require("../../configs/actionConfigs");

var _eslint = require("../actions/tools/eslint");

var _prettier = require("../actions/tools/prettier");

var _tsc = require("../actions/tools/tsc");

var _spinner = require("../cli/spinner");

var _getAnalyseFiles = require("../utils/getAnalyseFiles");

var _hasDependency = require("../utils/hasDependency");

var _isSelectedService = require("../utils/isSelectedService");

var _taskHook = require("../utils/taskHook");

const analysePreServices = ['eslint', 'prettier'];
exports.analysePreServices = analysePreServices;
const analyseSuffixServices = ['typescript'];
exports.analyseSuffixServices = analyseSuffixServices;
const analyseServices = [...analysePreServices, ...analyseSuffixServices];
exports.analyseServices = analyseServices;

const analyseTask = async (argv, {
  only,
  all,
  path,
  files
}) => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'analyse',
    type: 'pre'
  });
  const {
    eslintFiles,
    prettierFiles
  } = (await (0, _getAnalyseFiles.getAnalyseFiles)(argv, {
    all,
    files,
    path
  })) ?? {};

  if ((0, _isSelectedService.isSelectedService)(only, 'prettier')) {
    const prettierOptions = {
      write: !argv.ci,
      extension: argv.ci ? _actionConfigs.prettierCiExtensions : undefined,
      files: prettierFiles
    };
    await (0, _spinner.spinnerAction)((0, _prettier.prettierAction)(argv, prettierOptions), 'Analyse: Prettier');
  }

  if ((0, _isSelectedService.isSelectedService)(only, 'eslint')) {
    const eslintOptions = {
      write: !argv.ci,
      files: eslintFiles
    };
    await (0, _spinner.spinnerAction)((0, _eslint.eslintAction)(argv, eslintOptions), 'Analyse: ESLint');
  }

  if ((0, _isSelectedService.isSelectedService)(only, 'typescript')) {
    const hasTypescript = await (0, _hasDependency.hasDependency)(argv, {
      dependency: 'typescript',
      dependencyType: 'devDependencies'
    });

    if (hasTypescript) {
      await (0, _spinner.spinnerAction)((0, _tsc.tscAction)(argv, {
        mode: 'type-check'
      }), 'Analyse: Typescript');
    }
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'analyse',
    type: 'post'
  });
};

exports.analyseTask = analyseTask;