"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hooks = exports.gitTask = void 0;

var _path = require("path");

var _add = require("../actions/git/add");

var _ls = require("../actions/git/ls");

var _staged = require("../actions/git/staged");

var _commitlint = require("../actions/tools/commitlint");

var _existFiles = require("../cmd/existFiles");

var _cleanAnalyseFiles = require("../utils/cleanAnalyseFiles");

var _taskHook = require("../utils/taskHook");

var _analyseTask = require("./analyseTask");

var _manageTask = require("./manageTask");

var _testTask = require("./testTask");

const hooks = ['msg', 'commit'];
exports.hooks = hooks;

const gitTask = async (argv, {
  edit,
  hook
}) => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'git',
    type: 'pre'
  });
  const stagedFiles = await (0, _staged.gitStagedAction)(argv, {});
  const files = await (0, _existFiles.existFiles)(stagedFiles, argv.cwd);
  const {
    eslintFiles,
    mergedFiles,
    prettierFiles
  } = (0, _cleanAnalyseFiles.cleanAnalyseFiles)(files);
  const changedRelativeFiles = await (0, _ls.gitLsAction)(argv, {
    mode: 'all'
  });
  const changedAbsoluteFiles = new Set(changedRelativeFiles.map(file => (0, _path.join)(argv.root, file)));
  const intersectFiles = mergedFiles.filter(file => changedAbsoluteFiles.has(file));

  if (intersectFiles.length > 0) {
    const changedFiles = intersectFiles.map(file => `       ▸ ${file}\n`).join('');
    throw new Error(`The following files were changed after adding:\n${changedFiles}`);
  }

  switch (hook) {
    case 'commit':
      if (stagedFiles.length > 0) {
        await (0, _analyseTask.analyseTask)({ ...argv,
          ci: false
        }, {
          files: {
            eslintFiles,
            prettierFiles
          },
          only: _analyseTask.analysePreServices
        });
        await (0, _add.gitAddAction)(argv, {
          files
        });
      }

      break;

    case 'msg':
      if (typeof edit !== 'string' || edit.trim() === '') {
        throw new Error(`Argument "edit" is required at hook "${hook}"`);
      }

      await (0, _commitlint.commitlintAction)(argv, {
        edit
      });
      await (0, _analyseTask.analyseTask)({ ...argv,
        ci: false
      }, {
        files: {
          eslintFiles,
          prettierFiles
        },
        only: _analyseTask.analyseSuffixServices
      });
      await (0, _testTask.testTask)({ ...argv,
        ci: true
      }, {});
      await (0, _manageTask.manageTask)(argv, {});
      break;

    default:
      throw new Error(`The git hook "${hook}" is unknown`);
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'git',
    type: 'post'
  });
};

exports.gitTask = gitTask;