"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.manageTask = exports.manageServices = void 0;

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _config = require("../cli/config");

var _isSelectedService = require("../utils/isSelectedService");

var _taskHook = require("../utils/taskHook");

var _taskIsDiasbled = require("../utils/taskIsDiasbled");

var _manageDepsTask = require("./subTasks/manageDepsTask");

var _manageLicenseTask = require("./subTasks/manageLicenseTask");

var _managePackageLintTask = require("./subTasks/managePackageLintTask");

const manageServices = ['package', 'dependency', 'license'];
exports.manageServices = manageServices;

const manageTask = async (argv, {
  only
}) => {
  const packageLintDisable = await (0, _config.getConfig)(argv.root, 'packageLint.disable');
  const depsDisable = await (0, _config.getConfig)(argv.root, 'deps.disable');
  const licenseDisable = await (0, _config.getConfig)(argv.root, 'license.disable');
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  await (0, _taskHook.taskHook)(argv, {
    task: 'manage',
    type: 'pre'
  });

  if ((0, _isSelectedService.isSelectedService)(only, 'package')) {
    if (packageLintDisable === true) {
      await (0, _taskIsDiasbled.taskIsDiasbled)('package.json verification is disabled');
    } else {
      await (0, _managePackageLintTask.managePackageLintTask)(argv, {
        workspacePaths
      });
    }
  }

  if ((0, _isSelectedService.isSelectedService)(only, 'dependency')) {
    if (depsDisable === true) {
      await (0, _taskIsDiasbled.taskIsDiasbled)('Dependency verification is disabled');
    } else {
      await (0, _manageDepsTask.manageDepsTask)(argv, {
        workspacePaths
      });
    }
  }

  if ((0, _isSelectedService.isSelectedService)(only, 'license')) {
    if (licenseDisable === true) {
      await (0, _taskIsDiasbled.taskIsDiasbled)('License verification is disabled');
    } else {
      await (0, _manageLicenseTask.manageLicenseTask)(argv, {
        workspacePaths
      });
    }
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'manage',
    type: 'post'
  });
};

exports.manageTask = manageTask;