"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.manageDepsTask = void 0;

var _path = require("path");

var _tools = require("@kettil/tools");

var _depcheck = require("../../actions/tools/depcheck");

var _config = require("../../cli/config");

var _spinner = require("../../cli/spinner");

var _dependencyError = require("../../errors/dependencyError");

var _dependencyWarn = require("../../errors/dependencyWarn");

const manageDepsTask = async (argv, {
  workspacePaths
}) => {
  const configIgnorePackages = await (0, _config.getConfig)(argv.root, 'deps.ignore.packages');
  const ignorePackages = (0, _tools.isArray)(configIgnorePackages) ? configIgnorePackages.filter(_tools.isString) : [];
  await [argv.root, ...workspacePaths].reduce(async (promise, path) => promise.then(async () => {
    try {
      const subTitle = path === argv.root ? '' : `[${(0, _path.basename)(path)}]`;
      await (0, _spinner.spinnerAction)((0, _depcheck.depcheckAction)(argv, {
        path,
        ignorePackages
      }), `Dependency verification ${subTitle}`);
    } catch (error) {
      if (error instanceof _dependencyError.DependencyError) {
        argv.log.log(error.list);
        throw error;
      }

      if (!(error instanceof _dependencyWarn.DependencyWarn)) {
        throw error;
      }

      argv.log.log(error.list);
    }
  }), Promise.resolve());
};

exports.manageDepsTask = manageDepsTask;