"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.allSettledSequenceReduce = exports.allSettledSequence = void 0;

var _indent = require("../string/indent");

const allSettledSequenceReduce = async (promise, task) => promise.then(async errors => {
  try {
    await task();
  } catch (error) {
    if (error instanceof Error) {
      errors.push(error);
    } else {
      errors.push(new Error(`unknown error: ${(0, _indent.indent)(JSON.stringify(error, undefined, 2), 7).trimStart()}`));
    }
  }

  return errors;
});

exports.allSettledSequenceReduce = allSettledSequenceReduce;

const allSettledSequence = async tasks => {
  const errors = await tasks.reduce(async (promise, task) => allSettledSequenceReduce(promise, task), Promise.resolve([]));

  if (errors.length > 0) {
    const errorMessages = errors.map(error => error.stack ?? String(error));
    throw new Error(`Multiple errors found\n\n${(0, _indent.indent)(errorMessages.join('\n\n'), 7)}\n`);
  }
};

exports.allSettledSequence = allSettledSequence;